OC.L10N.register(
    "files_trashbin",
    {
    "Couldn't delete %s permanently" : "Konnt %s net permanent läschen",
    "Couldn't restore %s" : "Konnt %s net erëmhierstellen",
    "Deleted files" : "Geläscht Fichieren",
    "Restore" : "Erëmhierstellen",
    "Delete" : "Läschen",
    "Delete permanently" : "Permanent läschen",
    "Error" : "Fehler",
    "restored" : "erëmhiergestallt",
    "No deleted files" : "Keng geläscht Fichieren",
    "You will be able to recover deleted files from here" : "Du kanns geläscht Fichieren aus desëm Dossier erëmhierstellen",
    "No entries found in this folder" : "Keng Elementer an dësem Dossier fonnt",
    "Select all" : "All auswielen",
    "Name" : "Numm",
    "Deleted" : "Geläscht"
},
"nplurals=2; plural=(n != 1);");
